@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 
-"""This module contains operator to move data from Vertica to Hive."""
+"""This module contains an operator to move data from Vertica to Hive."""
 
 from collections import OrderedDict
 from tempfile import NamedTemporaryFile
@@ -26,7 +26,6 @@ import unicodecsv as csv
 from airflow.models import BaseOperator
 from airflow.providers.apache.hive.hooks.hive import HiveCliHook
 from airflow.providers.vertica.hooks.vertica import VerticaHook
-from airflow.utils.decorators import apply_defaults
 
 
 class VerticaToHiveOperator(BaseOperator):
@@ -60,8 +59,9 @@ class VerticaToHiveOperator(BaseOperator):
     :type delimiter: str
     :param vertica_conn_id: source Vertica connection
     :type vertica_conn_id: str
-    :param hive_conn_id: destination hive connection
-    :type hive_conn_id: str
+    :param hive_cli_conn_id: Reference to the
+        :ref:`Hive CLI connection id <howto/connection:hive_cli>`.
+    :type hive_cli_conn_id: str
 
     """
 
@@ -69,7 +69,6 @@ class VerticaToHiveOperator(BaseOperator):
     template_ext = ('.sql',)
     ui_color = '#b4e0ff'
 
-    @apply_defaults
     def __init__(
         self,
         *,
